@@ -4,7 +4,7 @@ Main interface for mobile service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_mobile import (
         Client,
         ListBundlesPaginator,
@@ -12,10 +12,8 @@ Usage::
         MobileClient,
     )
 
-    session = boto3.Session()
-
-    client: MobileClient = boto3.client("mobile")
-    session_client: MobileClient = session.client("mobile")
+    session = Session()
+    client: MobileClient = session.client("mobile")
 
     list_bundles_paginator: ListBundlesPaginator = client.get_paginator("list_bundles")
     list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
